@@ -26,14 +26,18 @@
 )]
 
 pub use crate::error::{Location, ParseError, ParseResult};
+pub use crate::heap_command::{HeapCommand, HeapType};
 pub use crate::isaspec::{parse_options, IsaSpec, ParseOptionError};
-pub use crate::parser::{parse_functions, parse_run_command, parse_test, ParseOptions};
+pub use crate::parser::{
+    parse_functions, parse_heap_command, parse_run_command, parse_test, ParseOptions,
+};
 pub use crate::run_command::{Comparison, Invocation, RunCommand};
 pub use crate::sourcemap::SourceMap;
 pub use crate::testcommand::{TestCommand, TestOption};
 pub use crate::testfile::{Comment, Details, Feature, TestFile};
 
 mod error;
+mod heap_command;
 mod isaspec;
 mod lexer;
 mod parser;
